@@ -88,9 +88,6 @@ char *enabled_modules = ""
 #ifdef ENABLE_FILEHASHES
 	", FileHashes"
 #endif
-#ifdef ENABLE_HTTP2
-	", HTTP/2"
-#endif
 #ifdef ENABLE_IPV6
 	", IPv6"
 #endif
@@ -658,13 +655,6 @@ int run_webserver(t_settings *settings) {
 			if (tls_set_config(&(binding->tls_config), &tls_setup) != 0) {
 				return -1;
 			}
-
-#ifdef ENABLE_HTTP2
-			if (binding->use_tls && binding->accept_http2) {
-				tls_accept_http2(binding->tls_config);
-			}
-#endif
-
 		}
 #endif
 
@@ -690,6 +680,7 @@ int run_webserver(t_settings *settings) {
 				return -1;
 			}
 		}
+
 		if (host->ca_cert_file != NULL) {
 			if (tls_load_ca_cert(host->ca_cert_file, &(host->ca_certificate)) != 0) {
 				return -1;
@@ -701,6 +692,14 @@ int run_webserver(t_settings *settings) {
 			}
 		}
 
+		if (host->hpkp_data != NULL) {
+			if (create_hpkp_header(host->hpkp_data) == -1) {
+				fprintf(stderr, "Error generating HPKP header for %s.\n", host->hostname.item[0]);
+				return -1;
+			}
+			host->hpkp_data->next = NULL;
+		}
+
 		/* Initialize Server Name Indication
 		 */
 		if ((host->private_key != NULL) && (host->certificate != NULL)) {
